@@ -272,9 +272,9 @@ static PyObject* alpha_calculation(PyObject *self, PyObject *args){
 		//alpha82	= atan((K1 + a8 * sin(alpha92)) / (K2 + a8 * cos(alpha92))) - alpha92;
 		//Ver4 change start
 		//alpha81 = math.atan(-(K1+a8*math.sin(alpha91))/(-(K2+a8*math.cos(alpha91)))) - alpha91
-		alpha81	= atan(-(K1 + a8 * sin(alpha91)) / (-(K2 + a8 * cos(alpha91)))) - alpha91;
+		alpha81	= atan2(-(K1 + a8 * sin(alpha91)) , (-(K2 + a8 * cos(alpha91)))) - alpha91;
         //alpha82 = math.atan(-(K1+a8*math.sin(alpha92))/(-(K2+a8*math.cos(alpha92)))) - alpha92
-		alpha82	= atan(-(K1 + a8 * sin(alpha92)) / (-(K2 + a8 * cos(alpha92)))) - alpha92;
+		alpha82	= atan2(-(K1 + a8 * sin(alpha92)) , (-(K2 + a8 * cos(alpha92)))) - alpha92;
 		//Ver4 change stop		
 		alpha71 = alpha91 + alpha81 - alpha987;
         alpha72 = alpha92 + alpha82 - alpha987;
